@@ -20,10 +20,15 @@ fn main() {
     let arguments = cli::Arguments::from_args();
     trace!("The command line arguments provided are {:?}.", arguments);
 
-    let commits = Commits::from_git(arguments.from_commit_hash);
-    let regexes = crate::utilities::regex::from(&arguments.effects);
+    let commits = if let Some(commit_hash) = arguments.from_commit_hash {
+        Commits::from_git_commit_hash(commit_hash)
+    } else if let Some(reference) = arguments.from_reference {
+        Commits::from_git_reference(reference)
+    } else {
+        unreachable!();
+    };
 
-    match commits.is_effected(&regexes) {
+    match commits.is_effected(&arguments.effects) {
         true => exit(SUCCESSFUL_EXIT_CODE),
         false => exit(ERROR_EXIT_CODE),
     }
